See also: DOG, Dog, dög, and 'dog

## English[edit]

A dog (a Labrador retriever)
English Wikipedia has an article on:
dog
Wikipedia

### Alternative forms[edit]

- darg, dawg, dug (dialectal)
- doggie, doggy, doggo (childish)

### Pronunciation[edit]

- (Received Pronunciation) IPA(key): /dɒɡ/

  - Audio (UK) "a dog" |  | (file)

  - Audio (UK) |  | (file)

- (General American) enPR: dôg, IPA(key): /dɔɡ/

  - Audio (US) |  | (file)

- (cot–caught merger, Canada) IPA(key): /dɑɡ/

  - Audio (cot-caught merger) |  | (file)

- Rhymes: -ɒɡ

### Etymology 1[edit]

From Middle English dogge[1] (akin to Scots dug), from Old English dogga, docga,[2][3] of uncertain origin.

The original meaning seems to have been a common dog, as opposed to a well-bred one, or something like 'cur', and perhaps later came to be used for stocky dogs. Possibly a pet-form diminutive with suffix -ga (compare frocga (“frog”), *picga (“pig”)), appended to a base *dog-, *doc- of unclear origin and meaning. One possibility is Old English dox (“dark, swarthy”) (compare frocga from frox).[4] Another proposal is that it derives from Proto-West Germanic *dugan (“to be suitable”), the origin of Old English dugan (“to be good, worthy, useful”), English dow, German taugen. The theory goes that it could have been an epithet for dogs, commonly used by children, meaning "good/useful animal."[5]. Another is that it is related to *docce (“stock, muscle”), from Proto-West Germanic *dokkā (“round mass, ball, muscle, doll”), whence English dock (“stumpy tail”).

In 14th-century England, hound (from Old English hund) was the general word for all domestic canines, and dog referred to a subtype resembling the modern mastiff and bulldog.[6] By the 16th century, dog had become the general word, and hound had begun to refer only to breeds used for hunting.[7] In the 16th century, the word dog was adopted by several continental European languages as their word for mastiff.[8]

Despite similarities in forms and meaning, not related to Mbabaram dog.

#### Noun[edit]

dog (countable and uncountable, plural dogs)

1. A mammal of the family Canidae:
   1. The species Canis familiaris (sometimes designated Canis lupus familiaris), domesticated for thousands of years and of highly variable appearance because of human breeding.
      - 1918, W[illiam] B[abington] Maxwell, chapter XVI, in The Mirror and the Lamp, Indianapolis, Ind.: The Bobbs-Merrill Company, →OCLC:
          The preposterous altruism too! […] Resist not evil. It is an insane immolation of self—as bad intrinsically as fakirs stabbing themselves or anchorites warping their spines in caves scarcely large enough for a fair-sized dog.
      - 1963, Margery Allingham, chapter 19, in The China Governess: A Mystery, London: Chatto & Windus, →OCLC:
          When Timothy and Julia hurried up the staircase to the bedroom floor, where a considerable commotion was taking place, Tim took Barry Leach with him. […]. The captive made no resistance and came not only quietly but in a series of eager little rushes like a timid dog on a choke chain.
        The dog barked all night long.
   2. Any member of the family Canidae, including domestic dogs, wolves, coyotes, jackals, foxes, and their relatives (extant and extinct); canid.
      - 1989, John L. Gittleman, Carnivore Behavior, Ecology, and Evolution, page 561:
          This includes the development of hyena-like bone crushers (Osteoborus and Borophagus), a large bone-crushing hunting dog (Aelurodon), and another borophagine frugivorous dog (Carpocyon).
   3. (often attributive) A male dog, wolf, or fox, as opposed to a bitch or vixen.
      - 1908, Dogdom, volume 9, page 337, column 1:
          Entirely disregarding sex, Ch. Searchlight has a beautiful Cocker head, but as he is a dog, his head is too fine and far too much upon the bitchy order.
      - 1928, Siegfried Sassoon, Memoirs of a Fox-Hunting Man, Penguin, published 2013, page 149:
          Firstly, he was there to encourage and assist the hounds (a scratch pack – mostly dog-hounds drafted from fox-hound kennels because they were over-sized) […]
2. (uncountable) The meat of this animal, eaten as food.
     Did you know that they eat dog in South Korea?
3. A person:
   1. (slang, derogatory) A dull, unattractive girl or woman.
        She’s a real dog.
   2. (slang) A man, guy, chap.
        You lucky dog!
   3. (derogatory) Someone who is cowardly, worthless, or morally reprehensible.
        Come back and fight, you dogs!
        You dirty dog.
      - 1599, Robert Greene, Alphonsus, King of Aragon, act 3:
          Blasphemous dog, I wonder that the earth / Doth cease from renting vnderneath thy feete, / To swallow vp those cankred corpes of thine.
      - 1611, The Holy Bible, […] (King James Version), London: […] Robert Barker, […], →OCLC, 2 Kings 8:13, column 1:
          And Hazael ſaid, But what, is thy ſeruant a dogge, that he ſhould doe this great thing?
      - 1886 October – 1887 January, H[enry] Rider Haggard, She: A History of Adventure, London: Longmans, Green, and Co., published 1887, →OCLC:
          [A]t last Mahomed's stood straight up upon its vertebræ, and glared at me through its empty eyeholes, and cursed me with its grinning jaws, because I, a dog of a Christian, disturbed the last sleep of a true believer.
   4. (slang) A sexually aggressive man.
      - 2005, “Stay Fly”, in Jordan Houston, Darnell Carlton, Paul Beauregard, Premro Smith, Marlon Goodwin, David Brown, Willie Hutchinson (lyrics), Most Known Unknown‎[4], performed by Three 6 Mafia (featuring Young Buck, 8 Ball, and MJG), Sony BMG:
          DJ Paul is a dog; one you do not trust.
4. A mechanical device or support:
   1. Any of various mechanical devices for holding, gripping, or fastening something, particularly with a tooth-like projection.
      - 2009, ForestWorks, Chainsaw Operator's Manual, page 41:
          Whenever possible, let the tree support the weight of the chainsaw. Pivot the saw, using the saw's dogs (spikes) as a fulcrum.
   3. A click or pallet adapted to engage the teeth of a ratchet wheel, to restrain the back action.
        Synonyms: click, pallet, pawl, ratchet
   4. A metal support for logs in a fireplace.
        The dogs were too hot to touch.
      - 1902, Arthur Conan Doyle, The Hound of the Baskervilles:
          In the great old-fashioned fireplace behind the high iron dogs a log-fire crackled and snapped.
   5. (transport, historical) A double-ended side spike driven through a hole in the flange of a rail on a tramway.
5. (cartomancy) The eighteenth Lenormand card.
6. A hot dog: a frankfurter, wiener, or similar sausage; or a sandwich made from this.
     Alternative form: 'dog
   - 1994 July 21, Faye Fiore, “Congress relishes another franking privilege: Meat lobby puts on the dog with exclusive luncheon for lawmakers – experts on pork”, in Los Angeles Times‎[5]:
       Congressmen gleefully wolfed down every imaginable version of the hot dog – smoked kielbasas, jumbo grillers, Big & Juicy's, kosher dogs and spiced dogs […]
7. (poker slang) An underdog.
8. (slang, chiefly in the plural) Foot.
     My dogs are barking! ― My feet hurt!
9. (Cockney rhyming slang) (from "dog and bone") Phone or mobile phone.
     My dog is dead.
       My mobile-phone battery has run out of charge and is no longer able to function.
10. One of the cones used to divide up a racetrack when training horses.
11. (informal) Something that performs poorly.
    - 1885, Robert H. Codrington, The Melanesian Languages, page 143:
        He gives his dog-Mota or dog-Fiji in exchange for Pigeon English.
      That modification turned his Dodge hemi into a dog.
    1. (film) A flop; a film that performs poorly at the box office.
       - 1969, Ski, volume 34, number 4, page 121:
           Blue was released, and as Redford had predicted, it was a dog.
       - 2012, Ronald L. Davis, Duke: The Life and Image of John Wayne:
           "When The Alamo was coming out, the word of mouth on it was that it was a dog," Chase said.
12. (firearms, archaic) A cock, as of a gun.
    - 1832, The Edinburgh Encyclopaedia, volume 10, page 164:
        To this succeeded the Snaplance [sic], in which a motion was given to the dog, or cock, and a movable plate of steel, called the frizel, or hammer, was placed vertically above the pan to receive the action of the flint.
13. (preceded by definite article) A dance having a brief vogue in the 1960s in which the actions of a dog were mimicked.
    - 1964, “What'd I Say”, Ray Charles (lyrics), performed by Elvis Presley:
        Hmm, see the girl with the red dress on
        She can do the dog all night long.
    - 1964, “C'mon And Swim”, Thomas Coman and Sylvester Stewart (Sly Stone) (lyrics), performed by Bobby Freeman:
        Just like the dog but not so low
        Like the hully gully but not so slow
        Now baby swim, baby do the swim.
    - 1967, Trudy Baker, Rachel Jones, Donald Bain (uncredited), Coffee, Tea, or Me?: The Uninhibited Memoirs of Two Airline Stewardesses, New York: Bantam Books, page 173:
        We had a lovely dance—luckily it was a slow number. I don't think Mr. Lincoln would have been up to the dog or a fast twist.

##### Synonyms[edit]

- (animal): taxonomic names: Canis familiaris, Canis domesticus, Canis familiarus domesticus, Canis canis, Canis aegyptius, Canis familiarus aegyptius, Canis melitaeus, Canis familiarus melitaeus, Canis molossus, Canis familiarus molossus, Canis saultor, Canis familiaris saultor
- (animal): domestic dog, hound, canine; see also Thesaurus:dog
- (male): stud, sire
- (meat): dogflesh, dog meat, fragrant meat
- (man): bloke (British), chap (British), dude, fellow, guy, man; see also Thesaurus:man
- (morally reprehensible person): cad, bounder, blackguard, fool, hound, heel, scoundrel
- (mechanical device): click, detent, pawl
- (metal support for logs): andiron, fire dog, dogiron

##### Hypernyms[edit]

- (animal): canid, quadruped

##### Hyponyms[edit]

- (animal):

- Afghan hound
- bloodhound
- chihuahua
- coonhound
- dachshund
- deerhound
- foxhound
- gazehound
- German shepherd
- greyhound
- hound
- Irish wolfhound
- New Guinea singing dog
- Norwegian elkhound
- otterhound
- pointer
- poodle
- retriever
- Russian wolfhound
- scenthound
- setter
- sheepdog
- shepherd
- sighthound
- spaniel
- staghound
- terrier
- wolfhound

##### Coordinate terms[edit]

- (male adult dog): bitch, pup, puppy

##### Derived terms[edit]

- a barking dog never bites
- a barking dog seldom bites
- a hit dog will holler
- aid dog
- alpha-dog
- alpha dog
- Alsatian dog
- and your little dog too
- an old dog for a hard road
- arson dog
- as sick as a dog
- assistance dog
- attack dog
- Australian cattle dog
- avalanche dog
- Azara's dog
- badger dog
- bait dog
- balloon dog
- barking dogs never bite, barking dogs seldom bite
- bench dog
- Bernese mountain dog
- beware of dog
- beware of the dog
- Big Dog
- big dog of the tanyard
- bird dog, bird-dog
- black dog
- bone-crushing dog
- bottom dog
- Brinjaree dog
- bulldog
- bush dog
- buy a dog and bark oneself
- Bắc Hà dog
- cadaver dog
- call off the dogs
- Canaan dog
- cant-dog
- Carolina dog
- carrot dog
- cash-sniffing dog
- Catahoula hog dog
- Catahoula leopard dog
- cat-and-dog, cat and dog
- cats and dogs
- cattle dog
- Caucasian shepherd dog
- cheese dog
- Chicago dog
- chili dog, chilli dog
- choke-dog
- Chongqing dog
- clever old dog
- companion dog
- coon dog
- corn dog
- corndog
- coy dog
- cunning dog
- curtail dog
- dagwood dog
- Danish dog
- designer dog
- detection dog
- devil dog
- diner's dog
- dirty dog
- dish dog
- dog act
- dog and bone
- dog and cat
- dog and maggot
- dog and pony show
- dog-and-pony show
- dog-ape, dog ape
- dog around
- dog ass
- dog attack
- dog bag
- dogbane
- dog basket
- dog-bear
- dog bed
- dog-bee
- dog-belt
- Dogberry
- dogberry
- dogberryism, Dogberryism
- dog biscuit
- dog-bludgeoner
- dog bone
- dog book
- dog bread
- dog breeding
- dog-brier
- dog cart, dog-cart
- dogcatcher, dog-catcher
- dogcatching
- dogcheap
- dog-cheap
- dog-cherry
- dog chew
- dog-child
- dog collar
- dog coupling
- dog crate
- dog curtain
- dog daisy
- dog dander
- dog dandruff
- dog-day
- dog day
- dog-day cicada
- dog days
- dog dirt
- dog doctor
- dogdom
- dog-doo
- dog door
- dogear, dog-ear, dog ear
- dog-eared
- dog eared
- dog eat dog, dog-eat-dog
- dog-egg
- dog egg
- dog-end
- dogette
- dogface
- dog-faced baboon
- dog fight
- dogfight
- dogfish
- dog flap
- dog flea
- dog flu
- dog fly
- dogfood, dog-food, dog food
- dogfought
- dog fouling
- dog-fox
- dog fox
- dog-friendly
- dog fucker
- dog fur
- Dogg
- dogged
- dogger
- doggerel
- doggery
- doggie
- doggish
- doggo
- doggone
- doggoned
- dog grass
- doggrel
- dog guide
- doggy
- doggy dog
- dog hair
- dog handler
- doghead
- dog-headed
- dog-hearted
- dog heavy
- doghood
- dog hook
- dog house
- doghouse
- dog hunter
- dog hutch
- dog in a blanket
- dog influenza
- dog in the hunt
- dog in the manger, dog-in-the-manger
- dogiron
- dog it
- dogitude
- dog killer
- dog Latin, Dog Latin
- dog-laurel
- dog lead, dog-lead
- dog leash, dog-leash
- dogleg
- dogless
- doglike
- dogling
- dogly
- dogman, dog man
- dog minder
- dog minding
- dog musher
- dog my cats
- dog nail
- dognap
- dognaper, dognapper
- dognapping
- dognaps
- dogness
- dog-nose
- dog-nosed
- dog officer
- dog out
- dogpaddle, dog-paddle, dog paddle
- dog park
- dog parsley
- dogpile, dog-pile, dog pile
- dog poo
- dog poop
- dogpoor
- dog pound
- dog-proof
- dog racing
- dogrel
- dog robber
- dog roll
- dog rope
- dog rose
- dog rough
- dog run
- dogs
- dog salmon
- dogs-bane
- dogsbody
- dog's breakfast
- dog's chance
- dog scooter
- dog screw
- dog's dangly bits
- dog's dinner
- dog's dirt
- dog's-ear
- dog's egg
- dogs have masters, cats have staff
- dogshit, dog shit
- dogshore
- dog shot
- dog-shot
- dog sit, dog-sit
- dogsitter
- dogsitting
- dogsled
- dogsledder
- dogsledding
- dog sledge
- dog sleep
- dog's-leg
- dog's letter
- dog's life
- dog-slow
- dog slow
- dog's mercury
- dog's mess
- dog's muck
- dogs of war
- dog soldier
- dog somebody's steps
- dogspeak
- dogspike, dog spike
- dog's-tail
- Dog Star
- dog station
- dog-stone
- dog's-tongue
- dog's-tooth
- dog tag
- dog tapeworm
- dog tax
- dog team
- dog tent
- dog that caught the car
- dog tick
- dog-tired, dog tired
- dogtooth, dog-tooth, dog tooth
- dog town
- dog trick
- dogtrot
- dog tucker
- dogvane
- dog-violet, dog violet
- dog vomit slime mold
- dog walk, dogwalk
- dogwalker, dog-walker, dog walker
- dogwalking, dog-walking, dog walking
- dog warden
- dogwash
- dogwatch
- dog-watch, dog watch
- dog-weary
- dog wheat
- dog whelk
- dogwhip, dog-whip
- dog whisperer
- dog whistle, dog-whistle
- dog-whistley
- dog-whistly
- dog who caught the tire
- dogwood
- dog work
- dog world
- dog year
- don't keep a dog and bark yourself
- dope dog
- double-dog dare, double-dog-dare, double dog dare
- down dog
- downward dog
- downward-facing dog
- drug dog
- Dulux dog
- earth dog
- everybody and his dog, everybody and their dog, everyone and his dog, everyone and their dog
- every dog has his day
- every dog has its day
- every dog must have his day
- every dog must have its day
- faithful as a dog
- feed dog
- feist dog
- female dog
- fice dog
- fight like cat and dog
- firedog, fire dog
- fire dogs
- fit as a butcher's dog
- flat dog
- flip dog
- fogdog
- foo dog, fu dog
- Frisian water dog
- fuck the dog
- Fuegian dog
- gag a dog off a gut wagon
- gay dog
- give a dog a bad name
- go to the dogs
- Goyet dog
- Greater Dog
- guarddog, guard-dog, guard dog
- guide dog
- gun dog
- gutter dog
- hair of the dog
- hair of the dog that bit one
- Hallstrom's dog
- hang dog, hang-dog
- have a dog and bark oneself
- have a dog in the fight
- have a dog in the race
- hearing dog
- hearing-ear dog
- help a lame dog over a stile
- helper dog
- herding dog
- hop dog
- horn dog, horn-dog
- hot diggety dog, hot diggity dog
- hotdog, hot-dog, hot dog
- hot-dog bun
- hotdogged, hot-dogged, hot dogged
- hotdogger, hot-dogger
- hotdoggery
- hound dog
- house dog
- hunting dog
- hyena dog
- Iceland dog
- idle as Ludlam's dog
- if you lie with dogs you will get fleas
- in a dog's age
- in the dog box
- in the doghouse
- Isle of Dogs
- it is easy to find a stick to beat a dog
- it's the hit dog that howls
- Jeju dog
- junkyard dog
- junkyard-dog
- kaffir dog
- kangaroo dog
- keep a dog and bark oneself
- kick a dog when it's down
- knock a dog off a gut wagon
- lapdog, lap-dog, lap dog
- lazy as Ludlam's dog
- lazy dog
- lazy dog bomb
- lead dog
- let sleeping dogs lie, let the sleeping dogs lie
- let the dog see the rabbit
- lie doggo
- lie like a dog
- like a dog in heat
- like a dog on heat
- like a dog with a bone
- like a dog with two dicks
- like a dog with two tails
- like a scalded dog
- lion dog
- little dog syndrome
- log dog
- look for a dog to kick
- lucky dog
- mad dog, mad-dog
- man bites dog
- miller's dog
- Miryang dog
- moon dog
- nanny dog
- New Guinea singing dog
- not-dog
- not dog
- not enough to hang a dog on
- one-dog night
- one man and a dog, one man and his dog
- on the Internet nobody knows you're a dog
- orange dog
- painted dog
- pariah dog
- Pavlov dog
- Pavlov's dog
- pelt of the dog
- penny dog
- pi-dog
- pie-dog, pye-dog
- pig dog
- plum pudding dog
- polar dog
- police dog
- poligar dog
- polygar dog
- pour cats and dogs, pour dogs and cats
- prairie dog
- pug dog, pug-dog
- Pungsan dog
- puppy dog, puppy-dog
- puppy-dog eyes
- puppy dog eyes
- put on the dog, put on dog
- raccoon dog
- raft dog
- rain cats and dogs, rain dogs and cats, rain like cats and dogs
- rat dog
- raw dog
- red dog
- rescue dog
- river dog
- road dog
- roundabout dog
- running dog
- salty dog
- sausage dog
- seadog, sea dog, sea-dog
- see a man about a dog
- seeing eye dog
- seeing-eye dog
- seizure dog
- service dog
- setting dog
- shaggy dog story, shaggy-dog story
- shaggy dog tale
- she-dog
- sheepdog, sheep dog
- shelter dog
- shepherd dog
- short-eared dog
- show dog
- sick as a dog
- singing dog
- skittle-dog
- sled dog
- sleep like a dog
- sleuth dog, sleuth-dog
- sling dog
- sly dog
- small dog syndrome
- small-eared dog
- sniffer dog
- snowdog
- sod a dog
- space dog
- spotted dog
- stink a dog off a gut wagon
- storm cats and dogs
- stray dog
- Sulimov dog
- sundog, sun dog
- support dog
- swing dog
- tail wagging the dog
- teacup dog
- that dog don't run
- that dog won't hunt
- that old dog won't hunt
- the dog ate my homework
- the proverbial dog that caught the car
- the quick brown fox jumps over the lazy dog
- there's life in the old dog yet
- the whole world and his dog
- three-dog night
- three dog night
- throw to the dogs
- tin dog
- tinned dog
- too much pudding will choke a dog
- top dog
- toy dog
- triple dog dare
- try it on the dog
- try it out on the dog
- turnspit dog
- two men and a dog
- underdog
- until the last dog is hung
- upward-facing dog
- veggiedog, veggie dog
- Velcro dog
- wag the dog
- walking the dog
- walk the dog
- war dog
- waterdog, water dog
- weiner dog, wiener dog
- wheel dog
- why keep a dog and bark yourself
- wild dog
- wolf dog
- wolf-dog
- work dog
- working dog
- work like a dog
- Yaghan dog
- yallar dog, yaller dog
- yard dog
- yellow dog
- you can't teach an old dog new tricks

##### Descendants[edit]

- Bislama: dog
- Gullah: dog
- Sranan Tongo: dagu
- Tok Pisin: dok
- Torres Strait Creole: dog

- → American Sign Language: Kop@Inside-PalmForward 1o@Inside
- → Dutch: dog
- → Esperanto: dogo
  - Ido: dogo
- → French: dogue
- → German: Dogge
- → Italian: dogo
  - → English: dogo
- → Kriol: dog
- → Portuguese: dogue
- → Russian: дог (dog)
- → Spanish: dogo
- → Volapük: dog, doeg

##### Translations[edit]

See dog/translations § Noun.

#### Verb[edit]

dog (third-person singular simple present dogs, present participle dogging, simple past and past participle dogged)

1. (transitive) To pursue with the intent to catch.
     Synonyms: chase, chase after, go after, pursue, tag, tail, track, trail
2. (transitive) To follow in an annoying or harassing way.
     The woman cursed him so that trouble would dog his every step.
   - 1749, Henry Fielding, The History of Tom Jones, a Foundling, volumes (please specify |volume=I to VI), London: A[ndrew] Millar, […], →OCLC:
       […] they were discovered in a very improper manner by the husband of the gypsy, who, from jealousy it seems, had kept a watchful eye over his wife, and had dogged her to the place, where he found her in the arms of her gallant.
   - 2012 January, Michael Riordan, “Tackling Infinity”, in American Scientist‎[6], volume 100, number 1, archived from the original on 30 April 2013, page 86:
       Some of the most beautiful and thus appealing physical theories, including quantum electrodynamics and quantum gravity, have been dogged for decades by infinities that erupt when theorists try to prod their calculations into new domains. Getting rid of these nagging infinities has probably occupied far more effort than was spent in originating the theories.
   - 2012 May 9, Jonathan Wilson, “Europa League: Radamel Falcao's Atlético Madrid rout Athletic Bilbao”, in the Guardian‎[7]:
       But this is not an Athletic that ever looks comfortable at the back – a criticism that has often dogged Marcelo Bielsa's sides.
   - 2021 June 21, Daisuke Wakabayashi, “Google Executives See Cracks in Their Company’s Success”, in The New York Times‎[8], →ISSN:
       Yet Google, which was founded in 1998, is dogged by the perception that its best days are behind it.
3. (transitive, nautical) To fasten a hatch securely.
     It is very important to dog down these hatches.
4. (intransitive, emerging usage in Britain) To watch, or participate, in sexual activity in a public place.
     I admit that I like to dog at my local country park.
   - 2012, The Onion Book of Known Knowledge, page 118:
       Lightning [is a] burst of charged particles that lights up the sky and allows onlookers to see who's dogging in the bushes without using a flashlight.
5. (intransitive, transitive) To intentionally restrict one's productivity as employee; to work at the slowest rate that goes unpunished.
     Synonyms: soldier, goldbrick
     A surprise inspection of the night shift found that some workers were dogging it.
6. (transitive, slang) To criticize.
   - 1999 March 30, “Shakedown”, in JAG, season 4, episode 18, via CBS:
       Harmon Rabb (David James Elliott): Are you dogging Harm's special meatless meatloaf?
       Sarah MacKenzie (Catherine Bell): Let's put it this way. If you were to make the Harmon Special on this ship, they'd have to unload it with the toxic waste.
7. (transitive, military) To divide (a watch) with a comrade.
   - 1902, Winfield Scott Schley, Record of Proceedings of a Court of Inquiry:
       A. We never stood 4 to 8 p.m. watches, sir. We dogged our watches.
       Q. I suppose that is 6 to 8 p.m., then; it is a little indistinct. I mean the second dog watch.
   - 2015, Tom Vetter, 30,000 Leagues Undersea:
       Meanwhile, we dogged the watch sections so that both halves of the crew could fetch full sea bags of uniforms and gear […]

##### Derived terms[edit]

- all dogged up

##### Translations[edit]

to pursue with the intent to catch

Bulgarian: преследвам (bg) (presledvam) Dutch: jagen (nl), vervolgen (nl) Finnish: jahdata (fi), ajaa takaa (fi) Georgian: ნადირობა (nadiroba) German: jagen (de), verfolgen (de), hetzen (de) Russian: преследовать (ru) (presledovatʹ) Spanish: perseguir (es)

to follow in an annoying way

Bulgarian: ходя по петите (hodja po petite) Dutch: plagen (nl), pesten (nl) Finnish: vainota (fi), ahdistaa (fi), jahdata (fi) German: verfolgen (de), plagen (de), an den Fersen bleiben

to fasten a hatch securely

Dutch: bevestigen (nl), vastmaken (nl) Finnish: lukita (fi), sulkea (fi) German: befestigen (de), sichern (de), fixieren (de), festmachen (de)

### Etymology 2[edit]

Clipping of dogshit.

#### Adjective[edit]

dog (not comparable)

1. (slang) Of inferior quality; dogshit.

### See also[edit]

- Category:en:Canids
- bark
- canine
- cynomorphic
- cynomorphism
- flea bag

### Further reading[edit]

- Michael Weisenberg (2000), The Official Dictionary of Poker (MGI/Mike Caro University, →ISBN
- dog on Wikipedia.Wikipedia
- List of sequenced animal genomes on Wikipedia.Wikipedia
- Canis on Wikispecies.Wikispecies
- Category:Dog on Wikimedia Commons.Wikimedia Commons
- Canis on Wikimedia Commons.Wikimedia Commons

### References[edit]

1. ^ Hans Kurath, Sherman M. Kuhn, Middle English Dictionary (1962, →ISBN), page 4, page 1204
2. ^ Joseph Bosworth and T. Northcote Toller (1898), “docga”, in An Anglo-Saxon Dictionary, 2nd edition, Oxford: Oxford University Press.
3. ^ Laurel Brinton, Alexander Bergs, Old English (2017, →ISBN), page 59: "In addition, the velar [ɡɡ] and palatal [ɡɡj] geminates could be written as <gg> or <cg>, as in <dogga> ~ <docga> ..."; Richard M. Hogg, Norman Francis Blake, The Cambridge History of the English Language (1992, →ISBN), volume 1, age 91 says much the same.
4. ^ Piotr Gąsiorowski, 2006. The Etymology of Old English *docga. Indogermanische Forschungen, 111.
5. ^ [1]
6. ^ [2]
7. ^ [3]
8. ^ Douglas Harper (2001–2024), “dog”, in Online Etymology Dictionary.

### Anagrams[edit]

- God, god

## Afrikaans[edit]

### Etymology[edit]

From Dutch docht.

### Pronunciation[edit]

- IPA(key): /dɔχ/

- Audio |  | (file)

### Verb[edit]

dog

1. Alternative form of dag (preterite of dink)

## Bislama[edit]

### Etymology[edit]

From English dog. Cognate with Tok Pisin dok.

### Pronunciation[edit]

- IPA(key): /ˈdoɡ/
- Hyphenation: dog

### Noun[edit]

dog

1. dog

### References[edit]

- Terry Crowley (2004) Bislama Reference Grammar, Honolulu: University of Hawaiʻi press, →ISBN, page 37

## Chinese[edit]

### Etymology 1[edit]

From English dog, which is translation of 狗 (gau2, “dog”), which is a homophone of 九 (gau2, “nine”), which is a euphemism of 鳩／鸠 (gau1, “fucking; stupid”).

#### Pronunciation[edit]

- Cantonese (Jyutping): dok1, gau2

- Cantonese
  - (Standard Cantonese, Guangzhou–Hong Kong)+
    - Jyutping: dok1, gau2
    - Yale: dōk, gáu
    - Cantonese Pinyin: dok7, gau2
    - Guangdong Romanization: dog1, geo2
    - Sinological IPA (key): /tɔːk̚⁵/, /kɐu̯³⁵/

#### Noun[edit]

dog

1. (Hong Kong Cantonese, Internet slang, leetspeak, euphemistic) Alternative form of 鳩／鸠 (gau1)

#### Adjective[edit]

dog

1. (Hong Kong Cantonese, Internet slang, leetspeak, euphemistic) Alternative form of 鳩／鸠 (gau1)

#### Derived terms[edit]

- on dog
- on dog dog

### Etymology 2[edit]

From English dog.

#### Pronunciation[edit]

- Cantonese (Jyutping): dok1

- Cantonese
  - (Standard Cantonese, Guangzhou–Hong Kong)+
    - Jyutping: dok1
    - Yale: dōk
    - Cantonese Pinyin: dok7
    - Guangdong Romanization: dog1
    - Sinological IPA (key): /tɔːk̚⁵/

#### Noun[edit]

dog

1. (Hong Kong Cantonese) The name of the Latin-script letter D.

##### See also[edit]

- boy

## Danish[edit]

### Etymology[edit]

From Old Danish dogh, which was borrowed from Middle Low German doch, ultimately from Proto-Germanic *þauh.

### Adverb[edit]

dog

1. however
     Det er dog ikke sikkert, at de taler sandt.
       It is, however, not certain that they are telling the truth.
2. Conveying impressedness, emotional affectation, bewilderment.
     Hvor er den hund dog nuttet!
       How cute that dog is!
     Sikke dramatisk du dog kan fremstille sagen!
       How dramatically you can present the matter!

### Conjunction[edit]

dog

1. though

## Dutch[edit]

### Etymology[edit]

Borrowed from English dog. Attested since the 16th century.

### Pronunciation[edit]

- IPA(key): /dɔx/

- Audio |  | (file)

- Hyphenation: dog
- Rhymes: -ɔx
- Homophone: doch

### Noun[edit]

dog m (plural doggen, diminutive dogje n)

1. A large dog, especially one of certain breeds.

#### Derived terms[edit]

- Deense dog

## Gullah[edit]

### Etymology[edit]

Inherited from English dog.

### Noun[edit]

dog

1. dog

## Kriol[edit]

### Etymology[edit]

From English dog.

### Noun[edit]

dog

1. dog

## Mbabaram[edit]

### Etymology[edit]

From *dwog(a), from *udwoga, from *gudwaga, from Proto-Pama-Nyungan *gudaga. Related to Dyirbal guda, Yidiny gudaga. False cognate of English dog.[1][2]

### Pronunciation[edit]

- IPA(key): /dɔɡ/[2]

### Noun[edit]

dog

1. dog

### References[edit]

1. ^ Language Hat, excerpting Dixon's Memoirs of a Field Worker
2. ↑ 2.0 2.1 Stephen R. Anderson, Languages: A Very Short Introduction (Oxford 2012), 36.

## Navajo[edit]

### Etymology[edit]

Onomatopoeic.

### Interjection[edit]

dog

1. thump, dub (sound of a heartbeat; thumping sound of a person walking on the roof of a house as heard by someone in the house)

#### Synonyms[edit]

- tsʼidog

## Norwegian Bokmål[edit]

### Pronunciation[edit]

- Audio |  | (file)

### Adverb[edit]

dog

1. however

### Conjunction[edit]

dog

1. though

## Polish[edit]

Polish Wikipedia has an article on:
dog
Wikipedia pl

### Etymology[edit]

Borrowed from English dog, from Middle English dogge, from Old English dogga, docga.

### Pronunciation[edit]

- IPA(key): /dɔk/

- Audio |  | (file)

- Rhymes: -ɔk
- Syllabification: dog
- Homophone: dok

### Noun[edit]

dog m anim

1. mastiff

#### Declension[edit]

Declension of dog

| singular | plural
--- | --- | ---
nominative | dog | dogi
genitive | doga | dogów
dative | dogowi | dogom
accusative | doga | dogi
instrumental | dogiem | dogami
locative | dogu | dogach
vocative | dogu | dogi

### Further reading[edit]

- dog in Wielki słownik języka polskiego, Instytut Języka Polskiego PAN
- dog in Polish dictionaries at PWN

## Portuguese[edit]

### Pronunciation[edit]

- (Brazil) IPA(key): /ˈdɔ.ɡi/

- (Brazil) IPA(key): /ˈdɔ.ɡi/
  - (Southern Brazil) IPA(key): /ˈdɔ.ɡe/

### Noun[edit]

dog m (plural dogs)

1. Clipping of hot dog.

## Romanian[edit]

### Etymology[edit]

Borrowed from French dogue, from English dog.

### Noun[edit]

dog m (plural dogi)

1. mastiff

#### Declension[edit]

Declension of dog

| singular | plural
--- | --- | ---
| indefinite articulation | definite articulation | indefinite articulation | definite articulation
nominative/accusative | (un) dog | dogul | (niște) dogi | dogii
genitive/dative | (unui) dog | dogului | (unor) dogi | dogilor
vocative | dogule | dogilor

## Swedish[edit]

### Pronunciation[edit]

- IPA(key): /duːɡ/

### Verb[edit]

dog

1. past indicative of dö

### Anagrams[edit]

- god

## Torres Strait Creole[edit]

### Etymology[edit]

From English dog.

### Noun[edit]

dog

1. dog

## Volapük[edit]

Volapük Wikipedia has an article on:
dog
Wikipedia vo

### Etymology[edit]

From English dog.

### Pronunciation[edit]

- IPA(key): [doɡ]

### Noun[edit]

dog (nominative plural dogs)

1. (male or female) dog

#### Declension[edit]

declension of dog

| singular | plural
--- | --- | ---
nominative | dog | dogs
genitive | doga | dogas
dative | doge | doges
accusative | dogi | dogis
vocative 1 | o dog! | o dogs!
predicative 2 | dogu | dogus

- 1 status as a case is disputed
- 2 in later, non-classical Volapük only

#### Derived terms[edit]

- bludadog
- dafadog
- dogacek
- dogadom
- dogahipul
- dogajipul
- dogakek
- dogalecek
- dogalif
- dogalucek
- dogarosad
- dogarosadabimül
- dogem
- dogibrid
- dogibridan
- dogibridöp
- dogihibridan
- dogihikälan
- dogijibridan
- dogijikälan
- dogik
- dogikolär
- dogikälan
- dogil
- dogilik
- doginulüdot
- dogül
- dogülik
- domadog
- dugadog
- farmadog
- flutülön dogi
- hidog
- hidogil
- hidogül
- hodog
- jidog
- jidogil
- jidogül
- jodog
- krigakäladog
- lievadog
- lupadog
- mitanadog
- pädritadog
- sadinadog
- sigretadog
- sismaladog
- sukadog
- sukäladog
- vümadog
- vümadogil
- yagadog

#### Related terms[edit]

- doeg
- toradoeg